@@ -2,4 +2,7 @@ mod add_hosted_service_strategy;
 pub use add_hosted_service_strategy::*;
 
 mod add_background_service_strategy;
-pub use add_background_service_strategy::*;
\ No newline at end of file
+pub use add_background_service_strategy::*;
+
+mod add_configuration_strategy;
+pub use add_configuration_strategy::*;
\ No newline at end of file
